==> eff-option_sjs1_3-7.0.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"option","t":"option","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax.html#","e":false,"i":"","n":"org.atnos.eff.syntax","t":"org.atnos.eff.syntax","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/option$.html#","e":false,"i":"","n":"option","t":"option extends option","d":"org.atnos.eff.syntax","k":"object","x":""},
{"l":"org/atnos/eff/syntax/option.html#","e":false,"i":"","n":"option","t":"option","d":"org.atnos.eff.syntax","k":"trait","x":""},
{"l":"org/atnos/eff/syntax/option.html#OptionEffectOps-fffff94b","e":false,"i":"","n":"OptionEffectOps","t":"OptionEffectOps[R, A](e: Eff[R, A]): OptionEffectOps[R, A]","d":"org.atnos.eff.syntax.option","k":"def","x":""},
{"l":"org/atnos/eff/syntax/option$OptionEffectOps.html#","e":false,"i":"","n":"OptionEffectOps","t":"OptionEffectOps[R, A](e: Eff[R, A])","d":"org.atnos.eff.syntax.option","k":"class","x":""},
{"l":"org/atnos/eff/syntax/option$OptionEffectOps.html#runOption-8c7","e":false,"i":"","n":"runOption","t":"runOption(implicit member: Member[Option, R]): Eff[Out, Option[A]]","d":"org.atnos.eff.syntax.option.OptionEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/option$OptionEffectOps.html#runOptionU-fffff336","e":false,"i":"","n":"runOptionU","t":"runOptionU[U](implicit member: Aux[Option, R, U]): Eff[U, Option[A]]","d":"org.atnos.eff.syntax.option.OptionEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/OptionCreation.html#","e":false,"i":"","n":"OptionCreation","t":"OptionCreation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/OptionCreation.html#_Option-0","e":false,"i":"","n":"_Option","t":"_Option[R] = Member[Option, R]","d":"org.atnos.eff.OptionCreation","k":"type","x":""},
{"l":"org/atnos/eff/OptionCreation.html#_option-0","e":false,"i":"","n":"_option","t":"_option[R] = MemberIn[Option, R]","d":"org.atnos.eff.OptionCreation","k":"type","x":""},
{"l":"org/atnos/eff/OptionCreation.html#fromOption-6d3","e":false,"i":"","n":"fromOption","t":"fromOption[R : _option, A](o: Option[A]): Eff[R, A]","d":"org.atnos.eff.OptionCreation","k":"def","x":""},
{"l":"org/atnos/eff/OptionCreation.html#none-cb0","e":false,"i":"","n":"none","t":"none[R : _option, A]: Eff[R, A]","d":"org.atnos.eff.OptionCreation","k":"def","x":""},
{"l":"org/atnos/eff/OptionCreation.html#some-7bd","e":false,"i":"","n":"some","t":"some[R : _option, A](a: A): Eff[R, A]","d":"org.atnos.eff.OptionCreation","k":"def","x":""},
{"l":"org/atnos/eff/OptionCreation$.html#","e":false,"i":"","n":"OptionCreation","t":"OptionCreation extends OptionCreation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/OptionEffect.html#","e":false,"i":"","n":"OptionEffect","t":"OptionEffect extends OptionCreation, OptionInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/OptionEffect$.html#","e":false,"i":"","n":"OptionEffect","t":"OptionEffect extends OptionEffect","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/OptionInterpretation.html#","e":false,"i":"","n":"OptionInterpretation","t":"OptionInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/OptionInterpretation.html#runOption-b17","e":false,"i":"","n":"runOption","t":"runOption[R, U, A](effect: Eff[R, A])(implicit m: Aux[Option, R, U]): Eff[U, Option[A]]","d":"org.atnos.eff.OptionInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/OptionInterpretation$.html#","e":false,"i":"","n":"OptionInterpretation","t":"OptionInterpretation extends OptionInterpretation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/option$.html#","e":false,"i":"","n":"option","t":"option extends OptionCreation, OptionInterpretation","d":"org.atnos.eff","k":"object","x":""}];

==> eff-option_sjs1_3-7.0.5-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"option","t":"option","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax.html#","e":false,"i":"","n":"org.atnos.eff.syntax","t":"org.atnos.eff.syntax","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/option$.html#","e":false,"i":"","n":"option","t":"option extends option","d":"org.atnos.eff.syntax","k":"object","x":""},
{"l":"org/atnos/eff/syntax/option.html#","e":false,"i":"","n":"option","t":"option","d":"org.atnos.eff.syntax","k":"trait","x":""},
{"l":"org/atnos/eff/syntax/option.html#OptionEffectOps-fffff94b","e":false,"i":"","n":"OptionEffectOps","t":"OptionEffectOps[R, A](e: Eff[R, A]): OptionEffectOps[R, A]","d":"org.atnos.eff.syntax.option","k":"def","x":""},
{"l":"org/atnos/eff/syntax/option$OptionEffectOps.html#","e":false,"i":"","n":"OptionEffectOps","t":"OptionEffectOps[R, A](e: Eff[R, A])","d":"org.atnos.eff.syntax.option","k":"class","x":""},
{"l":"org/atnos/eff/syntax/option$OptionEffectOps.html#runOption-8c7","e":false,"i":"","n":"runOption","t":"runOption(implicit member: Member[Option, R]): Eff[member.Out, Option[A]]","d":"org.atnos.eff.syntax.option.OptionEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/option$OptionEffectOps.html#runOptionU-fffff336","e":false,"i":"","n":"runOptionU","t":"runOptionU[U](implicit member: Aux[Option, R, U]): Eff[U, Option[A]]","d":"org.atnos.eff.syntax.option.OptionEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/OptionCreation.html#","e":false,"i":"","n":"OptionCreation","t":"OptionCreation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/OptionCreation.html#_Option-0","e":false,"i":"","n":"_Option","t":"_Option[R] = Member[Option, R]","d":"org.atnos.eff.OptionCreation","k":"type","x":""},
{"l":"org/atnos/eff/OptionCreation.html#_option-0","e":false,"i":"","n":"_option","t":"_option[R] = MemberIn[Option, R]","d":"org.atnos.eff.OptionCreation","k":"type","x":""},
{"l":"org/atnos/eff/OptionCreation.html#fromOption-6d3","e":false,"i":"","n":"fromOption","t":"fromOption[R : _option, A](o: Option[A]): Eff[R, A]","d":"org.atnos.eff.OptionCreation","k":"def","x":""},
{"l":"org/atnos/eff/OptionCreation.html#none-cb0","e":false,"i":"","n":"none","t":"none[R : _option, A]: Eff[R, A]","d":"org.atnos.eff.OptionCreation","k":"def","x":""},
{"l":"org/atnos/eff/OptionCreation.html#some-7bd","e":false,"i":"","n":"some","t":"some[R : _option, A](a: A): Eff[R, A]","d":"org.atnos.eff.OptionCreation","k":"def","x":""},
{"l":"org/atnos/eff/OptionCreation$.html#","e":false,"i":"","n":"OptionCreation","t":"OptionCreation extends OptionCreation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/OptionEffect.html#","e":false,"i":"","n":"OptionEffect","t":"OptionEffect extends OptionCreation, OptionInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/OptionEffect$.html#","e":false,"i":"","n":"OptionEffect","t":"OptionEffect extends OptionEffect","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/OptionInterpretation.html#","e":false,"i":"","n":"OptionInterpretation","t":"OptionInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/OptionInterpretation.html#runOption-b17","e":false,"i":"","n":"runOption","t":"runOption[R, U, A](effect: Eff[R, A])(implicit m: Aux[Option, R, U]): Eff[U, Option[A]]","d":"org.atnos.eff.OptionInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/OptionInterpretation$.html#","e":false,"i":"","n":"OptionInterpretation","t":"OptionInterpretation extends OptionInterpretation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/option$.html#","e":false,"i":"","n":"option","t":"option extends OptionCreation, OptionInterpretation","d":"org.atnos.eff","k":"object","x":""}];
